@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include "config.h"
@@ -31,7 +31,7 @@
 #include <math.h>
 #include <string.h>
 #include <gconf/gconf-client.h>
-#include <devkit-power-gobject/devicekit-power.h>
+#include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
 #include "egg-console-kit.h"
@@ -40,7 +40,7 @@
 #include "gpm-common.h"
 #include "gpm-prefs-core.h"
 #include "gpm-stock-icons.h"
-#include "gpm-prefs-server.h"
+#include "gpm-brightness.h"
 
 static void gpm_prefs_finalize (GObject *object);
 
@@ -48,7 +48,7 @@ static void gpm_prefs_finalize (GObject *object);
 
 struct GpmPrefsPrivate
 {
-	DkpClient		*client;
+	UpClient		*client;
 	GtkBuilder		*builder;
 	gboolean		 has_batteries;
 	gboolean		 has_lcd;
@@ -118,46 +118,6 @@ gpm_prefs_activate_window (GpmPrefs *prefs)
 	gtk_window_present (window);
 }
 
-/**
- * gpm_dbus_get_caps:
- * @method: The g-p-m DBUS method name, e.g. "AllowedSuspend"
- **/
-static gint
-gpm_dbus_get_caps (GpmPrefs *prefs)
-{
-	DBusGConnection *connection;
-	DBusGProxy *proxy = NULL;
-	GError *error = NULL;
-	gboolean ret;
-	gint value = 0;
-
-	connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
-	if (connection == NULL) {
-		egg_warning ("Couldn't connect to g-p-m %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	proxy = dbus_g_proxy_new_for_name (connection,
-					   GPM_DBUS_SERVICE,
-					   GPM_DBUS_PATH,
-					   GPM_DBUS_INTERFACE);
-	ret = dbus_g_proxy_call (proxy, "GetPreferencesOptions", &error,
-				 G_TYPE_INVALID,
-				 G_TYPE_INT, &value,
-				 G_TYPE_INVALID);
-	if (!ret) {
-		/* abort as the DBUS method failed */
-		egg_warning ("GetPreferencesOptions failed: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-out:
-	if (proxy != NULL)
-		g_object_unref (proxy);
-	return value;
-}
-
 /**
  * gpm_prefs_help_cb:
  * @widget: The GtkWidget object
@@ -468,11 +428,9 @@ gpm_prefs_checkbox_lock_cb (GtkWidget *widget, GpmPrefs *prefs)
 {
 	gboolean checked;
 	gchar *gpm_pref_key;
-	const gchar *widget_name;
 
 	checked = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));
 
-	widget_name = gtk_widget_get_name (widget);
 	gpm_pref_key = (char *) g_object_get_data (G_OBJECT (widget), "conf_key");
 	egg_debug ("Changing %s to %i", gpm_pref_key, checked);
 	gconf_client_set_bool (prefs->priv->conf, gpm_pref_key, checked, NULL);
@@ -575,7 +533,6 @@ prefs_setup_notification (GpmPrefs *prefs)
 {
 	gchar *icon_policy_str;
 	gint icon_policy;
-	GtkWidget *radiobutton_icon_always;
 	GtkWidget *radiobutton_icon_present;
 	GtkWidget *radiobutton_icon_charge;
 	GtkWidget *radiobutton_icon_low;
@@ -586,8 +543,6 @@ prefs_setup_notification (GpmPrefs *prefs)
 	icon_policy = gpm_icon_policy_from_string (icon_policy_str);
 	g_free (icon_policy_str);
 
-	radiobutton_icon_always = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
-					      "radiobutton_notification_always"));
 	radiobutton_icon_present = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
 					       "radiobutton_notification_present"));
 	radiobutton_icon_charge = GTK_WIDGET (gtk_builder_get_object (prefs->priv->builder,
@@ -598,14 +553,11 @@ prefs_setup_notification (GpmPrefs *prefs)
 					     "radiobutton_notification_never"));
 
 	is_writable = gconf_client_key_is_writable (prefs->priv->conf, GPM_CONF_UI_ICON_POLICY, NULL);
-	gtk_widget_set_sensitive (radiobutton_icon_always, is_writable);
 	gtk_widget_set_sensitive (radiobutton_icon_present, is_writable);
 	gtk_widget_set_sensitive (radiobutton_icon_charge, is_writable);
 	gtk_widget_set_sensitive (radiobutton_icon_low, is_writable);
 	gtk_widget_set_sensitive (radiobutton_icon_never, is_writable);
 
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_always),
-				      icon_policy == GPM_ICON_POLICY_ALWAYS);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_present),
 				      icon_policy == GPM_ICON_POLICY_PRESENT);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_charge),
@@ -615,8 +567,6 @@ prefs_setup_notification (GpmPrefs *prefs)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (radiobutton_icon_never),
 				      icon_policy == GPM_ICON_POLICY_NEVER);
 
-	g_object_set_data (G_OBJECT (radiobutton_icon_always), "policy",
-			   GINT_TO_POINTER (GPM_ICON_POLICY_ALWAYS));
 	g_object_set_data (G_OBJECT (radiobutton_icon_present), "policy",
 			   GINT_TO_POINTER (GPM_ICON_POLICY_PRESENT));
 	g_object_set_data (G_OBJECT (radiobutton_icon_charge), "policy",
@@ -628,8 +578,6 @@ prefs_setup_notification (GpmPrefs *prefs)
 
 	/* only connect the callbacks after we set the value, else the conf
 	 * keys gets written to (for a split second), and the icon flickers. */
-	g_signal_connect (radiobutton_icon_always, "clicked",
-			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
 	g_signal_connect (radiobutton_icon_present, "clicked",
 			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
 	g_signal_connect (radiobutton_icon_charge, "clicked",
@@ -638,20 +586,6 @@ prefs_setup_notification (GpmPrefs *prefs)
 			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
 	g_signal_connect (radiobutton_icon_never, "clicked",
 			  G_CALLBACK (gpm_prefs_icon_radio_cb), prefs);
-
-	if (prefs->priv->has_batteries) {
-		/* there's no use case for displaying this option */
-		gtk_widget_hide_all (radiobutton_icon_never);
-	}
-	if (prefs->priv->has_batteries == FALSE) {
-		/* Hide battery radio options if we have no batteries */
-		gtk_widget_hide_all (radiobutton_icon_charge);
-		gtk_widget_hide_all (radiobutton_icon_low);
-	}
-	if (prefs->priv->has_batteries == FALSE && prefs->priv->has_ups == FALSE) {
-		/* Hide battery present option if no ups or primary */
-		gtk_widget_hide_all (radiobutton_icon_present);
-	}
 }
 
 static void
@@ -925,13 +859,18 @@ gpm_prefs_init (GpmPrefs *prefs)
 {
 	GtkWidget *main_window;
 	GtkWidget *widget;
-	gint caps;
 	guint retval;
 	GError *error = NULL;
+	GPtrArray *devices = NULL;
+	UpDevice *device;
+	UpDeviceKind kind;
+	GpmBrightness *brightness;
+	gboolean ret;
+	guint i;
 
 	prefs->priv = GPM_PREFS_GET_PRIVATE (prefs);
 
-	prefs->priv->client = dkp_client_new ();
+	prefs->priv->client = up_client_new ();
 	prefs->priv->console = egg_console_kit_new ();
 	prefs->priv->conf = gconf_client_get_default ();
 	/* watch gnome-power-manager keys */
@@ -944,29 +883,51 @@ gpm_prefs_init (GpmPrefs *prefs)
 	/* get value of delay in gnome-session */
 	prefs->priv->idle_delay = gconf_client_get_int (prefs->priv->conf, GPM_CONF_IDLE_DELAY, NULL);
 
-	caps = gpm_dbus_get_caps (prefs);
-	egg_debug ("caps=%i", caps);
-
-	/* get properties from gnome-power-manager */
-	prefs->priv->has_batteries = ((caps & GPM_PREFS_SERVER_BATTERY) > 0);
-	prefs->priv->has_ups = ((caps & GPM_PREFS_SERVER_UPS) > 0);
-	prefs->priv->has_lcd = ((caps & GPM_PREFS_SERVER_BACKLIGHT) > 0);
-	prefs->priv->has_button_lid = ((caps & GPM_PREFS_SERVER_LID) > 0);
-	prefs->priv->has_button_suspend = TRUE;
-
 	/* are we allowed to shutdown? */
 	prefs->priv->can_shutdown = TRUE;
 	egg_console_kit_can_stop (prefs->priv->console, &prefs->priv->can_shutdown, NULL);
 
-	/* get values from DkpClient */
+	/* get values from UpClient */
+	prefs->priv->can_suspend = up_client_get_can_suspend (prefs->priv->client);
+	prefs->priv->can_hibernate = up_client_get_can_hibernate (prefs->priv->client);
+#if UP_CHECK_VERSION(0,9,2)
+	prefs->priv->has_button_lid = up_client_get_lid_is_present (prefs->priv->client);
+#else
 	g_object_get (prefs->priv->client,
-		      "can-suspend", &prefs->priv->can_suspend,
-		      "can-hibernate", &prefs->priv->can_hibernate,
+		      "lid-is-present", &prefs->priv->has_button_lid,
 		      NULL);
+#endif
+	prefs->priv->has_button_suspend = TRUE;
+
+	/* find if we have brightness hardware */
+	brightness = gpm_brightness_new ();
+	prefs->priv->has_lcd = gpm_brightness_has_hw (brightness);
+	g_object_unref (brightness);
+
+	/* get device list */
+	ret = up_client_enumerate_devices_sync (prefs->priv->client, NULL, &error);
+	if (!ret) {
+		egg_warning ("failed to get device list: %s", error->message);
+		g_error_free (error);
+	}
+
+	devices = up_client_get_devices (prefs->priv->client);
+	for (i=0; i<devices->len; i++) {
+		device = g_ptr_array_index (devices, i);
+		//kind = up_device_get_kind (device);
+		g_object_get (device,
+			      "kind", &kind,
+			      NULL);
+		if (kind == UP_DEVICE_KIND_BATTERY)
+			prefs->priv->has_batteries = TRUE;
+		if (kind == UP_DEVICE_KIND_UPS)
+			prefs->priv->has_ups = TRUE;
+	}
+	g_ptr_array_unref (devices);
 
 	prefs->priv->builder = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (prefs->priv->builder, GPM_DATA "/gpm-prefs.ui", &error);
-	if (error != NULL) {
+	if (retval == 0) {
 		egg_warning ("failed to load ui: %s", error->message);
 		g_error_free (error);
 	}
