@@ -39,11 +39,11 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
-#include <devkit-power-gobject/devicekit-power.h>
+#include <libupower-glib/upower.h>
 
 #include "egg-debug.h"
 
-#include "gpm-devicekit.h"
+#include "gpm-upower.h"
 #include "gpm-engine.h"
 #include "gpm-common.h"
 #include "gpm-stock-icons.h"
@@ -86,7 +86,7 @@ gpm_tray_icon_show (GpmTrayIcon *icon, gboolean enabled)
 
 /**
  * gpm_tray_icon_set_tooltip:
- * @tooltip: The tooltip text, e.g. "Batteries fully charged"
+ * @tooltip: The tooltip text, e.g. "Batteries charged"
  **/
 gboolean
 gpm_tray_icon_set_tooltip (GpmTrayIcon *icon, const gchar *tooltip)
@@ -95,11 +95,7 @@ gpm_tray_icon_set_tooltip (GpmTrayIcon *icon, const gchar *tooltip)
 	g_return_val_if_fail (GPM_IS_TRAY_ICON (icon), FALSE);
 	g_return_val_if_fail (tooltip != NULL, FALSE);
 
-#if GTK_CHECK_VERSION(2,15,0)
 	gtk_status_icon_set_tooltip_text (icon->priv->status_icon, tooltip);
-#else
-	gtk_status_icon_set_tooltip (icon->priv->status_icon, tooltip);
-#endif
 	return TRUE;
 }
 
@@ -120,14 +116,16 @@ gpm_tray_icon_get_status_icon (GpmTrayIcon *icon)
  * Loads a pixmap from disk, and sets as the tooltip icon
  **/
 gboolean
-gpm_tray_icon_set_icon (GpmTrayIcon *icon, const gchar *filename)
+gpm_tray_icon_set_icon (GpmTrayIcon *icon, GIcon *gicon)
 {
+	gchar *filename = NULL;
 	g_return_val_if_fail (icon != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_TRAY_ICON (icon), FALSE);
 
-	if (filename != NULL) {
+	if (gicon != NULL) {
+		filename = g_icon_to_string (gicon);
 		egg_debug ("Setting icon to %s", filename);
-		gtk_status_icon_set_from_icon_name (icon->priv->status_icon, filename);
+		gtk_status_icon_set_from_gicon (icon->priv->status_icon, gicon);
 
 		/* make sure that we are visible */
 		gpm_tray_icon_show (icon, TRUE);
@@ -138,6 +136,7 @@ gpm_tray_icon_set_icon (GpmTrayIcon *icon, const gchar *filename)
 		/* make sure that we are hidden */
 		gpm_tray_icon_show (icon, FALSE);
 	}
+	g_free (filename);
 	return TRUE;
 }
 
@@ -170,21 +169,6 @@ gpm_tray_icon_show_preferences_cb (GtkMenuItem *item, gpointer data)
 		egg_warning ("Couldn't execute command: %s", command);
 }
 
-/**
- * gpm_tray_icon_popup_cleared_cd:
- * @widget: The popup Gtkwidget
- *
- * We have to re-enable the tooltip when the popup is removed
- **/
-static void
-gpm_tray_icon_popup_cleared_cd (GtkWidget *widget, GpmTrayIcon *icon)
-{
-	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
-	egg_debug ("clear tray");
-	g_object_ref_sink (widget);
-	g_object_unref (widget);
-}
-
 /**
  * gpm_tray_icon_class_init:
  **/
@@ -201,19 +185,23 @@ gpm_tray_icon_class_init (GpmTrayIconClass *klass)
  * gpm_tray_icon_add_device:
  **/
 static guint
-gpm_tray_icon_add_device (GpmTrayIcon *icon, GtkMenu *menu, const GPtrArray *array, DkpDeviceType type)
+gpm_tray_icon_add_device (GpmTrayIcon *icon, GtkMenu *menu, const GPtrArray *array, UpDeviceKind kind)
 {
 	guint i;
 	guint added = 0;
-	gchar *icon_name;
-	gchar *label;
+	gchar *percentage_str;
 	GtkWidget *item;
+	GtkWidget *label_title;
+	GtkWidget *label_percentage;
 	GtkWidget *image;
+	GtkWidget *hbox;
+	GtkWidget *hbox_align;
 	const gchar *object_path;
 	const gchar *desc;
-	DkpDevice *device;
-	DkpDeviceType type_tmp;
+	UpDevice *device;
+	UpDeviceKind kind_tmp;
 	gdouble percentage;
+	GIcon *gicon = NULL;
 
 	/* find type */
 	for (i=0;i<array->len;i++) {
@@ -221,61 +209,123 @@ gpm_tray_icon_add_device (GpmTrayIcon *icon, GtkMenu *menu, const GPtrArray *arr
 
 		/* get device properties */
 		g_object_get (device,
-			      "type", &type_tmp,
+			      "kind", &kind_tmp,
 			      "percentage", &percentage,
 			      NULL);
 
-		if (type != type_tmp)
+		if (kind != kind_tmp)
 			continue;
 
-		object_path = dkp_device_get_object_path (device);
+		object_path = up_device_get_object_path (device);
 		egg_debug ("adding device %s", object_path);
 		added++;
 
-		/* generate the label */
-		desc = gpm_device_type_to_localised_text (type, 1);
-		label = g_strdup_printf ("%s (%.1f%%)", desc, percentage);
-		item = gtk_image_menu_item_new_with_label (label);
+		/* generate the labels */
+		desc = gpm_device_kind_to_localised_string (kind, 1);
+		percentage_str = g_strdup_printf ("%.0f%%", percentage);
+
+		/* align title and percentage in columns */
+		hbox = gtk_hbox_new (FALSE, 3);
+		gtk_widget_show (hbox);
+
+		/* left align the device text */
+		hbox_align = gtk_hbox_new (FALSE, 0);
+		gtk_widget_show (hbox_align);
+		label_title = gtk_label_new (desc);
+		gtk_widget_show (label_title);
+		gtk_box_pack_start (GTK_BOX (hbox_align), label_title, FALSE, FALSE, 0);
+
+		/* center align the percentage */
+		label_percentage = gtk_label_new (percentage_str);
+		gtk_widget_show (label_percentage);
+
+		/* add to the menu item */
+		item = gtk_image_menu_item_new ();
+		gtk_container_add (GTK_CONTAINER (item), hbox);
+		gtk_box_pack_start (GTK_BOX (hbox), hbox_align, TRUE, TRUE, 3);
+		gtk_box_pack_start (GTK_BOX (hbox), label_percentage, FALSE, FALSE, 3);
 
 		/* generate the image */
-		icon_name = gpm_devicekit_get_object_icon (device);
-		image = gtk_image_new_from_icon_name (icon_name, GTK_ICON_SIZE_MENU);
+		gicon = gpm_upower_get_device_icon (device, TRUE);
+		image = gtk_image_new_from_gicon (gicon, GTK_ICON_SIZE_MENU);
 		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (item), TRUE);
 
 		/* callback and add the the menu */
 		g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (gpm_tray_icon_show_info_cb), icon);
 		g_object_set_data (G_OBJECT (item), "object-path", (gpointer) object_path);
+
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-		g_free (icon_name);
-		g_free (label);
+		g_free (percentage_str);
+		g_object_unref (gicon);
 	}
 	return added;
 }
 
 /**
- * gpm_tray_icon_create_menu:
- *
- * Display the popup menu.
+ * gpm_tray_icon_add_primary_device:
  **/
 static void
-gpm_tray_icon_create_menu (GpmTrayIcon *icon, guint32 timestamp)
+gpm_tray_icon_add_primary_device (GpmTrayIcon *icon, GtkMenu *menu, UpDevice *device)
+{
+	GtkWidget *item;
+	gchar *time_str;
+	gchar *string;
+	gint64 time_to_empty = 0;
+
+	/* get details */
+	g_object_get (device,
+		      "time-to-empty", &time_to_empty,
+		      NULL);
+
+	/* convert time to string */
+	time_str = gpm_get_timestring (time_to_empty);
+
+	/* TRANSLATORS: % is a timestring, e.g. "6 hours 10 minutes" */
+	string = g_strdup_printf (_("%s remaining"), time_str);
+	item = gtk_image_menu_item_new_with_label (string);
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	g_free (time_str);
+	g_free (string);
+}
+
+/**
+ * gpm_tray_icon_create_menu:
+ *
+ * Create the popup menu.
+ **/
+static GtkMenu *
+gpm_tray_icon_create_menu (GpmTrayIcon *icon)
 {
 	GtkMenu *menu = (GtkMenu*) gtk_menu_new ();
 	GtkWidget *item;
 	GtkWidget *image;
 	guint dev_cnt = 0;
 	GPtrArray *array;
+	UpDevice *device = NULL;
+
+	/* show the primary device time remaining */
+	device = gpm_engine_get_primary_device (icon->priv->engine);
+	if (device != NULL) {
+		gpm_tray_icon_add_primary_device (icon, menu, device);
+		item = gtk_separator_menu_item_new ();
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+	}
 
 	/* add all device types to the drop down menu */
 	array = gpm_engine_get_devices (icon->priv->engine);
-	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, DKP_DEVICE_TYPE_BATTERY);
-	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, DKP_DEVICE_TYPE_UPS);
-	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, DKP_DEVICE_TYPE_MOUSE);
-	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, DKP_DEVICE_TYPE_KEYBOARD);
-	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, DKP_DEVICE_TYPE_PDA);
-	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, DKP_DEVICE_TYPE_PHONE);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_BATTERY);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_UPS);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_MOUSE);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_KEYBOARD);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_PDA);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_PHONE);
+#if UP_CHECK_VERSION(0,9,5)
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_MEDIA_PLAYER);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_TABLET);
+	dev_cnt += gpm_tray_icon_add_device (icon, menu, array, UP_DEVICE_KIND_COMPUTER);
+#endif
 	g_ptr_array_unref (array);
 
 	/* skip for things like live-cd's and GDM */
@@ -297,6 +347,38 @@ gpm_tray_icon_create_menu (GpmTrayIcon *icon, guint32 timestamp)
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 skip_prefs:
+	if (device != NULL)
+		g_object_unref (device);
+	return menu;
+}
+
+/**
+ * gpm_tray_icon_popup_cleared_cd:
+ * @widget: The popup Gtkwidget
+ *
+ * We have to re-enable the tooltip when the popup is removed
+ **/
+static void
+gpm_tray_icon_popup_cleared_cd (GtkWidget *widget, GpmTrayIcon *icon)
+{
+	g_return_if_fail (GPM_IS_TRAY_ICON (icon));
+	egg_debug ("clear tray");
+	g_object_ref_sink (widget);
+	g_object_unref (widget);
+}
+
+/**
+ * gpm_tray_icon_popup_menu:
+ *
+ * Display the popup menu.
+ **/
+static void
+gpm_tray_icon_popup_menu (GpmTrayIcon *icon, guint32 timestamp)
+{
+	GtkMenu *menu;
+
+	menu = gpm_tray_icon_create_menu (icon);
+
 	/* show the menu */
 	gtk_widget_show_all (GTK_WIDGET (menu));
 	gtk_menu_popup (GTK_MENU (menu), NULL, NULL,
@@ -316,7 +398,7 @@ static void
 gpm_tray_icon_popup_menu_cb (GtkStatusIcon *status_icon, guint button, guint32 timestamp, GpmTrayIcon *icon)
 {
 	egg_debug ("icon right clicked");
-	gpm_tray_icon_create_menu (icon, timestamp);
+	gpm_tray_icon_popup_menu (icon, timestamp);
 }
 
 
@@ -330,7 +412,7 @@ static void
 gpm_tray_icon_activate_cb (GtkStatusIcon *status_icon, GpmTrayIcon *icon)
 {
 	egg_debug ("icon left clicked");
-	gpm_tray_icon_create_menu (icon, gtk_get_current_event_time());
+	gpm_tray_icon_popup_menu (icon, gtk_get_current_event_time());
 }
 
 /**
